"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParameterService__Consumer = exports.ParameterService__Producer = void 0;
const soa_client_1 = require("@cross-lab-project/soa-client");
const soa_client_2 = require("@cross-lab-project/soa-client");
const tiny_typed_emitter_1 = require("tiny-typed-emitter");
const ServiceType = 'https://api.goldi-labs.de/serviceTypes/parameter';
function checkConfig(config) {
    if (config.serviceType !== ServiceType) {
        //throw Error("Service Configuration needs to be for MessageService type");
    }
}
class ParameterService__Producer extends tiny_typed_emitter_1.TypedEmitter {
    constructor(serviceId) {
        super();
        this.serviceType = ServiceType;
        this.serviceDirection = soa_client_1.Producer;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceType: this.serviceType,
            serviceId: this.serviceId,
            serviceDirection: this.serviceDirection,
        };
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new soa_client_2.DataChannel();
        if (connection.tiebreaker) {
            connection.transmit(serviceConfig, 'data', channel);
        }
        else {
            connection.receive(serviceConfig, 'data', channel);
        }
        this.channel = channel;
        this.emit('setup', { parameters: serviceConfig.parameters });
    }
    async updateParameter(parameter, value) {
        if (this.channel !== undefined) {
            await this.channel.ready();
            this.channel.send(JSON.stringify({ parameter: parameter, value: value }));
        }
    }
}
exports.ParameterService__Producer = ParameterService__Producer;
class ParameterService__Consumer extends tiny_typed_emitter_1.TypedEmitter {
    constructor(serviceId, parametersDescriptions) {
        super();
        this.serviceType = ServiceType;
        this.serviceDirection = soa_client_1.Consumer;
        this.parameterDescriptions = parametersDescriptions;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceType: this.serviceType,
            serviceId: this.serviceId,
            serviceDirection: this.serviceDirection,
            parameters: this.parameterDescriptions,
        };
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new soa_client_2.DataChannel();
        channel.ondata = this.handleData.bind(this);
        if (connection.tiebreaker) {
            connection.transmit(serviceConfig, 'data', channel);
        }
        else {
            connection.receive(serviceConfig, 'data', channel);
        }
    }
    handleData(data) {
        if (typeof data === 'string') {
            const msg = JSON.parse(data);
            this.emit('update', { parameter: msg.parameter, value: msg.value });
        }
    }
}
exports.ParameterService__Consumer = ParameterService__Consumer;
//# sourceMappingURL=parameter_service.js.map