import { Consumer, Producer, } from '@cross-lab-project/soa-client';
import { DataChannel } from '@cross-lab-project/soa-client';
import { TypedEmitter } from 'tiny-typed-emitter';
const ServiceType = 'https://api.goldi-labs.de/serviceTypes/parameter';
function checkConfig(config) {
    if (config.serviceType !== ServiceType) {
        //throw Error("Service Configuration needs to be for MessageService type");
    }
}
export class ParameterService__Producer extends TypedEmitter {
    constructor(serviceId) {
        super();
        this.serviceType = ServiceType;
        this.serviceDirection = Producer;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceType: this.serviceType,
            serviceId: this.serviceId,
            serviceDirection: this.serviceDirection,
        };
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new DataChannel();
        if (connection.tiebreaker) {
            connection.transmit(serviceConfig, 'data', channel);
        }
        else {
            connection.receive(serviceConfig, 'data', channel);
        }
        this.channel = channel;
        this.emit('setup', { parameters: serviceConfig.parameters });
    }
    async updateParameter(parameter, value) {
        if (this.channel !== undefined) {
            await this.channel.ready();
            this.channel.send(JSON.stringify({ parameter: parameter, value: value }));
        }
    }
}
export class ParameterService__Consumer extends TypedEmitter {
    constructor(serviceId, parametersDescriptions) {
        super();
        this.serviceType = ServiceType;
        this.serviceDirection = Consumer;
        this.parameterDescriptions = parametersDescriptions;
        this.serviceId = serviceId;
    }
    getMeta() {
        return {
            serviceType: this.serviceType,
            serviceId: this.serviceId,
            serviceDirection: this.serviceDirection,
            parameters: this.parameterDescriptions,
        };
    }
    setupConnection(connection, serviceConfig) {
        checkConfig(serviceConfig);
        const channel = new DataChannel();
        channel.ondata = this.handleData.bind(this);
        if (connection.tiebreaker) {
            connection.transmit(serviceConfig, 'data', channel);
        }
        else {
            connection.receive(serviceConfig, 'data', channel);
        }
    }
    handleData(data) {
        if (typeof data === 'string') {
            const msg = JSON.parse(data);
            this.emit('update', { parameter: msg.parameter, value: msg.value });
        }
    }
}
//# sourceMappingURL=parameter_service.js.map